# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See LICENSE.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

###################################################################

## Global Variables

## This file is added to minimize the false positives flagged during R CMD check.
## Example: afterhours_trend: no visible binding for global variable 'Date'

###################################################################

utils::globalVariables(
  c(
    "Date",
    "Start",
    "End",
    "PersonId",
    "group",
    "Period",
    "outcome",
    ".",
    "After_hours_collaboration_hours",
    "Employee_Count",
    "bins",
    "Metric",
    "Hours",
    "Collaboration_hours",
    "Collaboration_hrs",
    "Instant_message_hours",
    "bucket_hours",
    "Employees",
    "Total",
    "Value",
    "Email_hours",
    "External_network_size",
    "Networking_outside_company",
    "Ext_network_size",
    "Ext_network_breadth",
    "CH_ratio",
    "Emails_sent",
    "Email_ratio",
    "WorkingEndTimeSetInOutlook",
    "WorkingStartTimeSetInOutlook",
    "WorkdayRange",
    "WorkdayFlag",
    "WorkdayFlag1",
    "WorkdayFlag2",
    "TimeInvestorOrg",
    "CollaboratorOrg",
    "metric_prop",
    "output_list",
    "n_unique",
    "attribute",
    "NA_per",
    "no visible global function definition for head",
    "mean_collab",
    "holidayweek",
    "ymin",
    "ymax",
    "z_score",
    "Organization",
    "flag_nkw",
    "perc",
    "tenure_years",
    "odd_tenure",
    "Internal_network_size",
    "Networking_outside_organization",
    "Int_network_size",
    "Int_network_breadth",
    "Workweek_span",
    "Meeting_hours",
    "Meetings",
    "After_hours_meeting_hours",
    "Low_quality_meeting_hours",
    "Generated_workload_email_recipients",
    "After_hours_email_hours",
    "Total_focus_hours",
    "variable",
    "Multitasking_meeting_hours",
    "Redundant_meeting_hours__organizational_",
    "Conflicting_meeting_hours",
    "Meeting_count",
    "perc_after_hours_m",
    "perc_low_quality",
    "perc_Multitasking",
    "perc_Redundant",
    "perc_conflicting",
    "Redundant_meeting_hours__lower_level_",
    "HourType",
    "extract_prop",
    "extract_raw",
    "RawHours",
    "MeetingType",
    "Attendee_meeting_hours",
    "AttendeeMeetingHours",
    "Prop",
    "Duration",
    "Attendees",
    "Percent",
    "value2",
    "x",
    "y",
    "Meeting_hours_with_manager",
    "coattendman_rate",
    "bucket_coattendman_rate",
    "Meeting_hours_with_manager_1_on_1",
    "mgr1on1",
    "coattendande",
    "mgrRel",
    "xmin",
    "xmax",
    "bucket_manager_1_on_1",
    "Minutes_with_manager_1_on_1",
    "Metrics",
    "Values",
    "Checks",
    "Variables",
    "UniqueValues",
    "MissingValues",
    "Examples",
    "KPI",
    "After",
    "Before",
    "delta",
    "perc_diff",
    "Mybins",
    "Employee_perc",
    "cluster",
    "key",
    "clusters",
    "label",
    "Signals",
    "StartEnd",
    "Before_start",
    "Within_hours",
    "After_end",
    "Cases",
    "subjectFlag",
    "Subject",
    "line",
    "text",
    "word",
    "name",
    "freq",
    "pre_group",
    "Utilization_hrs",
    "UH_bin",
    "UH_over_45",
    "h_clust",
    "dist_m",
    "Signals_Total",
    "Signals_sent",
    "Personas",
    "Employee_count",
    "external_network_plot",
    "total",
    "value",
    "prop",
    "ODDS",
    "..input_var2",
    ".N",
    ".SD",
    "Freq",
    "PersonCount",
    "Shifts",
    "Shoulders",
    "per",
    "sent",
    "Fill",
    "PersonWeekId",
    "WeekCount",
    "WeekPercentage",
    "patternRank",
    "Count",
    "Day_Span",
    "First_signal",
    "Last_signal",
    "MeetingHoursInLongOrLargeMeetings",
    "Percentage",
    "TenureYear",
    "calculation",
    "perc_nkw",
    "value_rescaled",
    "values",
    "cleaned_data",
    "zscore",
    "StrongTieType",
    "TieOrigin_PersonId",
    "TieDestination_PersonId",
    "Attribute 1",
    "Attribute 2",
    "Attribute 3",
    "Community",
    "Group",
    "N",
    "OrgGroup",
    "PercentageExplained",
    "V1",
    "V2",
    "Variable",
    "c1",
    "c2",
    "c3",
    "colour",
    "feature_1",
    "feature_1_value",
    "feature_2",
    "feature_2_value",
    "feature_3",
    "feature_3_value",
    "from",
    "percentage",
    "print_str",
    "pval",
    "sum_na",
    "to",
    "top_group",
    "AttendanceRate",
    "DurationHours",
    "Emails_sent_during_meetings",
    "Emails_sent_per_attendee_hour",
    "Invitees",
    "IsRecurring",
    "Mean_AttendanceRate",
    "Mean_Attendees",
    "Mean_DurationHours",
    "Mean_Emails_sent_per_attendee_hour",
    "Mean_Invitees",
    "MeetingId",
    "NRecurring",
    "Sum_Attendee_meeting_hours",
    "Total_meeting_cost",
    "Attendee hours",
    "DaySpan",
    "Domain",
    "Hour",
    "PANEL",
    "Time_in_self_organized_meetings",
    "Type",
    "labelpos",
    "Cadence_of_1_on_1_meetings_with_manager",
    "IV",
    "Meetings_with_manager_1_on_1",
    "org_size",
    "var",
    "var1",
    "var2",
    "where",
    "WOE",
    "ActivityLevel",
    "Attributes",
    "FirstValue",
    "Flexibility",
    "HRAttribute",
    "identifier",
    "PersonasNet",
    "Unique values",
    "Collaboration_hours_external",
    ".GRP",
    "Id",
    "betweenness",
    "closeness",
    "degree",
    "eigenvector",
    "node_size",
    "pagerank"
    )
)
